@@ -43,7 +43,7 @@ class StaticScraper:
         print("[3] self.filter_by_threshold(self, thresh_index, thresh_function, \n\tinputname = None, outputname = None)")
         print("[4] self.collapse_columns(self, column_indices, inputname = None, outputname = None)", end = '\n\n')
     
-    def save_record(self, filename = None, start_empty = False):
+    def __save_record(self, filename = None, start_empty = False):
         
         filename = (filename if (filename != None) else self.filename)
         
@@ -53,7 +53,7 @@ class StaticScraper:
 
         if (start_empty):
         
-            self.erase_file(filename)
+            self.__erase_file(filename)
         
         with open(filename, 'a', encoding = 'UTF-8') as FILE:
             
@@ -61,42 +61,42 @@ class StaticScraper:
                 
                 FILE.write(str(scraped) + '\n')
     
-    def erase_file(self, filename):
+    def __erase_file(self, filename):
         
         with open(filename, 'w', encoding = 'UTF-8') as FILE:
         
             FILE.write('')
     
-    def buffer_exceeded(self):
+    def __buffer_exceeded(self):
         
         return (len(self.scrapeList) == self.buffer)
     
-    def scrape_webpage(self, webpage):
+    def __scrape_webpage(self, webpage):
         
         self.scrapeList = []
         
-        itemList = self.custom_find(
+        itemList = self.__custom_find(
             BS(requests.get(webpage).text, 'lxml'),
             self.webinfo.f_item
         )
         
         for item in itemList:
             
-            self.scrapeList.append( [ self.custom_find(item, attr) for attr in self.webinfo.f_attr ] )
+            self.scrapeList.append( [ self.__custom_find(item, attr) for attr in self.webinfo.f_attr ] )
             
-            if (self.buffer_exceeded()):
+            if (self.__buffer_exceeded()):
                 
-                self.save_record()
+                self.__save_record()
         
                 self.scrapeList = []
         
         if (len(self.scrapeList)):
             
-            self.save_record()
+            self.__save_record()
             
             self.scrapeList = []
     
-    def prompt_overwrite(self, filename):
+    def __prompt_overwrite(self, filename):
         
         if ((filename != None) and (os.path.isfile(filename))):
             
@@ -108,7 +108,7 @@ class StaticScraper:
                 
                 print("Will overwite the destination file.", end = '\n\n')
             
-                self.erase_file(filename)
+                self.__erase_file(filename)
             
             elif ('n' in userInput):
             
@@ -124,7 +124,7 @@ class StaticScraper:
     
     def scrape_webpages(self, start = 1, pages = 1):
         
-        if (self.prompt_overwrite(self.filename) == None):
+        if (self.__prompt_overwrite(self.filename) == None):
           
             return None
         
@@ -132,13 +132,13 @@ class StaticScraper:
             
             print("Scraping page {} of {} pages.".format(page, start + pages - 1))
             
-            self.scrape_webpage(self.webinfo.f_url + self.webinfo.f_page.format(page))
+            self.__scrape_webpage(self.webinfo.f_url + self.webinfo.f_page.format(page))
             
             print("\tScraped page {} of {} pages.".format(page, start + pages - 1), end = '\n\n')
             
             time.sleep(self.timesleep)
     
-    def custom_find(self, source, format_info):
+    def __custom_find(self, source, format_info):
         
         result = (source.find_all if format_info['multiple'] else source.find)
         
@@ -152,7 +152,7 @@ class StaticScraper:
         
         file_name = (inputname if (inputname != None) else self.filename)
         
-        if (self.prompt_overwrite(outputname) == None):
+        if (self.__prompt_overwrite(outputname) == None):
             
             return None
         
@@ -178,15 +178,15 @@ class StaticScraper:
                         
                         self.scrapeList.append(data)
                     
-                    if ((outputname != None) and (self.buffer_exceeded())):
+                    if ((outputname != None) and (self.__buffer_exceeded())):
                         
-                        self.save_record(filename = outputname)
+                        self.__save_record(filename = outputname)
                         
                         self.scrapeList = []
                 
                 if (len(self.scrapeList)):
                     
-                    self.save_record(filename = outputname, start_empty = (outputname == None))
+                    self.__save_record(filename = outputname, start_empty = (outputname == None))
                     
                     self.scrapeList = []
                 
@@ -200,7 +200,7 @@ class StaticScraper:
             
             print("Error: Could not open {}".format(file_name), end = '\n\n')
     
-    def _extract(self, source, column_indices):
+    def __extract(self, source, column_indices):
         
         return (source if (len(column_indices) > 1) else source[0])
     
@@ -208,7 +208,7 @@ class StaticScraper:
         
         file_name = (inputname if (inputname != None) else self.filename)
         
-        if (self.prompt_overwrite(outputname) == None):
+        if (self.__prompt_overwrite(outputname) == None):
             
             return None
         
@@ -228,17 +228,17 @@ class StaticScraper:
                 
                 for data in DATA:
                     
-                    self.scrapeList.append(self._extract([ x for index, x in enumerate(eval(data)) if index in column_indices ], column_indices))
+                    self.scrapeList.append(self.__extract([ x for index, x in enumerate(eval(data)) if index in column_indices ], column_indices))
                     
-                    if ((outputname != None) and (self.buffer_exceeded())):
+                    if ((outputname != None) and (self.__buffer_exceeded())):
                         
-                        self.save_record(filename = outputname)
+                        self.__save_record(filename = outputname)
                         
                         self.scrapeList = []
                         
                 if (len(self.scrapeList)):
                     
-                    self.save_record(filename = outputname, start_empty = (outputname == None))
+                    self.__save_record(filename = outputname, start_empty = (outputname == None))
                     
                     self.scrapeList = []
                     
